@@ -42,7 +42,7 @@ def main_menu(items, selected, title=None, search=None, white=False,
         'search': search,
         'position': position,
         'white': bool(white),
-    }
+        }
 
 @register.inclusion_tag('bob/tab_menu.html')
 def tab_menu(items, selected, side=None):
@@ -59,7 +59,7 @@ def tab_menu(items, selected, side=None):
         'items': items,
         'selected': selected,
         'side': side,
-    }
+        }
 
 @register.inclusion_tag('bob/sidebar_menu.html')
 def sidebar_menu(items, selected):
@@ -73,7 +73,7 @@ def sidebar_menu(items, selected):
     return {
         'items': items,
         'selected': selected,
-    }
+        }
 
 @register.inclusion_tag('bob/sidebar_menu_subitems.html')
 def sidebar_menu_subitems(item, selected):
@@ -84,11 +84,12 @@ def sidebar_menu_subitems(item, selected):
     return {
         'item': item,
         'selected': selected,
-    }
+        }
 
 @register.inclusion_tag('bob/pagination.html')
 def pagination(page, show_all=False, show_csv=False,
-                fugue_icons=False, url_query=None, neighbors=1):
+               fugue_icons=False, url_query=None, neighbors=1,
+               query_variable_name='page'):
     """
     Display pagination for a list of items.
 
@@ -106,17 +107,25 @@ def pagination(page, show_all=False, show_csv=False,
             'show_csv': show_csv,
             'fugue_icons': fugue_icons,
             'url_query': url_query,
-        }
+            }
     paginator = page.paginator
     page_no = page.number
     pages = paginator.page_range[max(0, page_no - 1 - neighbors):
-                                 min(paginator.num_pages, page_no + neighbors)]
+    min(paginator.num_pages, page_no + neighbors)]
+
     if 1 not in pages:
         pages.insert(0, 1)
         pages.insert(1, '...')
     if paginator.num_pages not in pages:
         pages.append('...')
         pages.append(paginator.num_pages)
+    urls = []
+    for item in pages:
+        if item == '...':
+            urls.append(changed_url(url_query, query_variable_name, page_no))
+        else:
+            urls.append(changed_url(url_query, query_variable_name, item))
+    url_pages = zip(pages, urls)
     return {
         'paginator': paginator,
         'page_no': page_no,
@@ -126,20 +135,21 @@ def pagination(page, show_all=False, show_csv=False,
         'show_csv': show_csv,
         'fugue_icons': fugue_icons,
         'url_query': url_query,
+        'url_previous_page': changed_url(url_query, query_variable_name, page_no-1),
+        'url_next_page': changed_url(url_query, query_variable_name, page_no+1),
+        'url_pages': url_pages,
+        'url_all': changed_url(url_query, query_variable_name, 0)
     }
 
-@register.filter
-def bob_page(query, page):
-    """Modify the query string of an URL to change the ``page`` argument."""
-
+def changed_url(query, name, value):
     if not query:
-        return 'page=%s' % page
+        return '%s=%s' % (name, value)
     query = query.copy()
-    if page is not None and page not in ('1', 1):
-        query['page'] = page
+    if value is not None and value not in ('1', 1):
+        query[name] = value
     else:
         try:
-            del query['page']
+            del query[name]
         except KeyError:
             pass
     return query.urlencode()
@@ -178,4 +188,3 @@ def timesince_limited(d):
             return d.strftime('%H:%M')
     else:
         return d
-
